function spectrumEst = BR_FBIAA_2(availData,N,S,q,K,nbrIaaIter,specEstOld)
% spectrumEst = BR_FBIAA_2(availData,N,S,q,K,nbrIaaIter,specEstOld)
%
% Block-Recursive Fast Periodically Gapped IAA, BR-F-BIAA_2.
%
% Computational efficient implementation of the BIAA algorithm that can be
% used in the scenario of periodically gapped data. This means that data is
% available in a specific repeated pattern, for example [1 1 1 0 0 1 1 1 0
% 0]. This example then has two blocks of pattern [1 1 1 0 0] where '1'
% means data is available and '0' that the sample is missing.
%
% This method was first published in:
%   A. Jakobsson, G. O. Glentis and E. Gudmundson, ''Computationally
%   Efficient Time-Recursive IAA-Based Blood Velocity Estimation'', IEEE
%   Transactions on Signal Processing.
%
% IN:
%  availData : vector of available data (ie. with missing data removed!)
%  N : total time window, ie. number of samples incl. the missing samples
%  S : data segment size, ie. length of each block of data incl. missing samples
%  q : number of available data elements within a data segment
%  K : number of frequency points at which to compute the spectrum
%  nbrIaaIter : number of IAA iterations during the initialization phase
%  specEstOld : spectrum for previous iteration
%
% OUT:
%  spectrumEst : the estimated spectrum
%
% Erik Gudmundson, March 2012
%

if isempty(specEstOld)
  init = 1;
else
  init = 0;
end

%Call subroutines
if init %init phase
  spectrumEst = pg_iaa_fast(availData,N,S,q,K,nbrIaaIter);
else
  spectrumEst = pg_iaa_fast_1_iter(availData,N,S,q,K,specEstOld);
end
