function spectrumEst = QN_FBIAA_2(availData,N,S,q,K,nbrIaaIter,qn)
% spectrumEst = QN_FBIAA_2(availData,N,S,q,K,nbrIaaIter,qn)
%
% Fast Periodically Gapped IAA with a Quasi-Newton algorithm, QN-F-BIAA_2.
%
% Computational efficient implementation of the BIAA algorithm that can be
% used in the scenario of periodically gapped data. This means that data is
% available in a specific repeated pattern, for example [1 1 1 0 0 1 1 1 0
% 0]. This example then has two blocks of pattern [1 1 1 0 0] where '1'
% means data is available and '0' that the sample is missing.
%
% This method was first published in:
%   A. Jakobsson, G. O. Glentis and E. Gudmundson, ''Computationally
%   Efficient Time-Recursive IAA-Based Blood Velocity Estimation'', IEEE
%   Transactions on Signal Processing.
%
% IN:
%  availData : vector of available data (ie. with missing data removed!)
%  N : total time window, ie. number of samples incl. the missing samples
%  S : data segment size, ie. length of each block of data incl. missing samples
%  q : number of available data elements within a data segment
%  K : number of frequency points at which to compute the spectrum
%  nbrIaaIter : number of IAA iterations during the initialization phase
%  qn : order of AR approximation (must be smaller than the number of
%       sub-blocks used, ie. N/S)
%
% OUT:
%  spectrumEst : the estimated spectrum
%
% Erik Gudmundson, March 2012
%

%Call subroutine
spectrumEst = pg_iaa_fast_qn(availData,N,S,q,K,nbrIaaIter,qn);
