function bveDataFiltered = meanFilter(bveData,windowVec)
% bveDataFiltered = meanFilter(bveData,windowVec)
%
% Do a mean filter of the data in order to smooth it.
%
% IN:
%  bveData : The blood velocity estimation data, of size 
%            nbrOfFreqPts x nbrOfSpectralLinesPerImages x nbrOfImages.
%  windowVec : Window vector for the mean filter, for example a triangle:
%              winVecTmp = linspace(0,1,5); 
%              winVec = [winVecTmp(2:end) winVecTmp(end-1:-1:2)];
%
% OUT:
%  bveDataFiltered : The filtered data of same size as the original data.
%
% Erik Gudmundson, October 2012
%


nbrLinesPerImage = size(bveData,2);
noImages = size(bveData,3);

bveDataFiltered = zeros(size(bveData));
for k0 = 1:noImages
  for k1 = 1:nbrLinesPerImage
    %Do the convolution
    bveDataFiltered(:,k1,k0) = conv(bveData(:,k1,k0),windowVec,'same');
  end
end