function [welchRefSpec] = refSpectrumWelch(data,nbrOfFreqs)
% [welchRefSpec] = refSpectrumWelch(data,nbrOfFreqs)
%
% Compute reference spectrum from the blood velocity data using Welch's 
% method applying a Hanning window on the data. 
%
% IN:
%  data       : Matrix of data, where each row corresponds to samples at a 
%               certain depth. If the data is now zero mean, the mean is 
%               removed.
%  nbrOfFreqs : The number of frequency points for the computed spectrum
%
% OUT:
%  welchRefSpec : The average spectrum over all depths.
%
% By Erik Gudmundson, 12 March 2012
%  

%Get size of the data
[nbrDepthSamples,nbrEmissions] = size(data);

%%  Calculate the reference spectrogram for all the data
welchRefSpec = 0;
for k = 1:nbrDepthSamples
  %First, remove the stationary mean of the signal at current depth
  sig = ( data(k,:) - mean(data(k,:)) )'.*hanning(nbrEmissions);
  %Update the spectrum
  welchRefSpec = welchRefSpec + fftshift(abs(fft(sig,nbrOfFreqs)/nbrEmissions).^2);
end
%Flip the spectrum
welchRefSpec = flipud(welchRefSpec);
