function [Ac,Bc,c,a,b,af,ab]=clwr(Rr,kn,kg,x)
%
% LWR for Toeplitz block solver
%
% Rc=x
%
% R [kn*kg,kn*kg] Toeplitz block
% kg*kg block entries
% R_i [kn,kn]
%
% G.O. Glentis, UoP 2010
%
%
% Rr => first block column of R
% kg => block size
% kn => entry size
% x  => right hand side vector
% Ac, Bc <= displacement matrices of R^(-1)
% c <= R^(-1)x
%
%

[Ng,LL]=size(x);
af=Rr(1:kn,1:kn);
ab=af;
rf=Rr(kn+1:2*kn,1:kn);
ab=(ab+ab')/2;
iab=inv(ab); iab=(iab+iab')/2;
a=-iab*rf;
b=-iab*rf';
kc=-iab*x(1:kn,:);
c=kc;
af=af+rf'*a;
ab=ab+rf*b;
ab=(ab+ab')/2;

for il=1:kg-2
  bc=x(1+il*kn:(il+1)*kn,:)+b'*x(1:il*kn,:);
  iab=inv(ab);
  iab=(iab+iab')/2;
  kc=-iab*bc;
  c=[c;zeros(kn,LL)]+[b;eye(kn)]*kc;
  bn=b;
  an=a;
  betafbt=Rr(kn+1:(il+2)*kn,:)'*[bn;eye(kn)];
  betafb=betafbt';
  kf=-iab*betafb;
  a=[a;zeros(kn,kn)]+[b;eye(kn)]*kf;
  iaf=inv(af); iaf=(iaf+iaf')/2;
  kb=-iaf*betafb';
  af=af+betafb'*kf;
  af=(af+af')/2;
  ab=ab+betafb*kb;
  ab=(ab+ab')/2;
  b=[zeros(kn);bn]+[eye(kn);an]*kb;
end
il=il+1;
bc=x(1+il*kn:(il+1)*kn,:)+b'*x(1:il*kn,:);
iab=inv(ab); iab=(iab+iab')/2;
kc=-iab*bc;
c=[c;zeros(kn,LL)]+[b;eye(kn)]*kc;
c=-c;



A=[eye(kn);a];
afc=chol(af); iafc=inv(afc);
Ac=A*iafc;
B=[b;eye(kn)];
abc=chol(ab); iabc=inv(abc);
Bc=B*iabc;


