function f = pg_iaa_fast_1_iter(xg,N,S,q,K,fold)
% f = pg_iaa_fast_1_iter(xg,N,S,q,K,fold)
%
% Fast Periodically Gapped IAA, block-recursive.
%
% Use pg_iaa_fast() to get the initial estimates!
%
% Computational efficient implementation of the BIAA algorithm that can be
% used in the scenario of periodically gapped data. This means that data is
% available in a specific repeated pattern, for example [1 1 1 0 0 1 1 1 0
% 0]. This example then has two blocks of pattern [1 1 1 0 0] where '1'
% means data is available and '0' that the sample is missing.
%
% This method, referred to as BR-F-BIAA_2, was first published in:
%   A. Jakobsson, G. O. Glentis and E. Gudmundson, ''Computationally
%   Efficient Time-Recursive IAA-Based Blood Velocity Estimation'', IEEE
%   Transactions on Signal Processing.
%
% IN:
%  xg : vector of available data (ie. with missing data removed!)
%  N  : total time window, ie. number of samples incl. the missing samples
%  S  : data segment size, ie. length of each block of data incl. missing samples
%  q  : number of available data elements within a data segment
%  K  : number of frequency points at which to compute the spectrum
%  fold : spectrum for previous iteration
%
% OUT:
%  f   : the spectrum
%
% G.O. Glentis, UoP 2010

seg=S;
kn=q;
kg=N/S; % number of segments
Ng=kg*q;
n=[0:N-1]';
%
%  Create gap pattern
mg=[];
for i=1:kg
  mg=[mg;ones(q,1);zeros(S-q,1)];
end
mg=logical(mg);
ng=n(mg);

c=xg;
q=(ifft(fold))*K;
RR=toeplitz(q,conj(q(1:kn)));
Rr=RR(mg,:);
[Ac,Bc,c]=clwr(Rr,kn,kg,xg);

xxg=c;
xxgn=zeros(N,1);
xxgn(mg)=xxg;
giaa_num=fft([xxgn;zeros(K-N,1)]);
fa1=pgap_coef_gs(Ac,Bc,kn,kg,N,seg);
Fa=fft([fa1;zeros(K-2*N+1,1)]);
D=exp((j*2*pi*(N-1)/K)*[0:K-1]');
Fa=real(D.*Fa);
giaa_den=[Fa(1);Fa(end:-1:2)];
gff=giaa_num./giaa_den;
giaaf=abs(gff).^2; % IAA spectrum

f=giaaf;



